@@ -69,7 +69,7 @@ class PandasConversionsTestCase(unittest.TestCase):
         rpyp.activate()
         rp_s = robjects.conversion.py2ri(s)
         rpyp.deactivate()
-        self.assertEqual(rinterface.SexpVector, type(rp_s))
+        self.assertEqual(rinterface.FloatSexpVector, type(rp_s))
 
     def testSeries_issue264(self):
         Series = pandas.core.series.Series
@@ -82,6 +82,13 @@ class PandasConversionsTestCase(unittest.TestCase):
         str(rp_s)
         self.assertEqual(rinterface.ListSexpVector, type(rp_s))
 
+    def testCategorical(self):
+        factor = robjects.vectors.FactorVector(('a', 'b', 'a'))
+        rpyp.activate()
+        rp_c = robjects.conversion.ri2py(factor)
+        rpyp.deactivate()
+        self.assertEqual(pandas.Categorical, type(rp_c))
+
     def testRepr(self):
         # this should go to testVector, with other tests for repr()
         l = (('b', numpy.array([True, False, True], dtype=numpy.bool_)),
